@@ -1,5 +1,5 @@
 # src/hpmpy_project/__init__.py
-"""hpmpy-project - Transforming Energy Supply System (M)odellIng Framework."""
+"""hpmpy-project."""
 from importlib.metadata import version
 
 __version__ = version(__name__)
